% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rStickBreakingPrior.R
\name{rStickBreakingPrior}
\alias{rStickBreakingPrior}
\title{Random Draw From Stick Breaking Prior}
\usage{
rStickBreakingPrior(alpha, K)
}
\arguments{
\item{alpha}{The concentration parameter.}

\item{K}{The number of weights to generate.}
}
\value{
A vector of component weights.
}
\description{
Draw weights from the stick-breaking prior.
}
\examples{
weights <- rStickBreakingPrior(1, 50)
}
